Class: Google::Apis::FirebaseappdistributionV1alpha::FirebaseAppDistributionService

Inherits:
Core::BaseService
  • Object
show all
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/service.rb

Overview

Firebase App Distribution API

Examples:

require 'google/apis/firebaseappdistribution_v1alpha'

Firebaseappdistribution = Google::Apis::FirebaseappdistributionV1alpha # Alias the module
service = Firebaseappdistribution::FirebaseAppDistributionService.new

See Also:

Constant Summary collapse

DEFAULT_ENDPOINT_TEMPLATE =
"https://firebaseappdistribution.$UNIVERSE_DOMAIN$/"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeFirebaseAppDistributionService

Returns a new instance of FirebaseAppDistributionService.



47
48
49
50
51
52
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 47

def initialize
  super(DEFAULT_ENDPOINT_TEMPLATE, '',
        client_name: 'google-apis-firebaseappdistribution_v1alpha',
        client_version: Google::Apis::FirebaseappdistributionV1alpha::GEM_VERSION)
  @batch_path = 'batch'
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



40
41
42
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 40

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



45
46
47
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 45

def quota_user
  @quota_user
end

Instance Method Details

#batch_project_app_test_case_delete(parent, google_firebase_appdistro_v1alpha_batch_delete_test_cases_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleProtobufEmpty

Deletes multiple test cases.

Parameters:

  • parent (String)

    Required. The parent resource of the test cases being deleted. Format: projects/project_number/apps/app``

  • google_firebase_appdistro_v1alpha_batch_delete_test_cases_request_object (Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaBatchDeleteTestCasesRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



568
569
570
571
572
573
574
575
576
577
578
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 568

def batch_project_app_test_case_delete(parent, google_firebase_appdistro_v1alpha_batch_delete_test_cases_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+parent}/testCases:batchDelete', options)
  command.request_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaBatchDeleteTestCasesRequest::Representation
  command.request_object = google_firebase_appdistro_v1alpha_batch_delete_test_cases_request_object
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleProtobufEmpty::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleProtobufEmpty
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#batch_project_app_test_case_update(parent, google_firebase_appdistro_v1alpha_batch_update_test_cases_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaBatchUpdateTestCasesResponse

Updates multiple test cases.

Parameters:

  • parent (String)

    Required. The parent resource of the test cases being updated. Format: projects/project_number/apps/app``

  • google_firebase_appdistro_v1alpha_batch_update_test_cases_request_object (Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaBatchUpdateTestCasesRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



602
603
604
605
606
607
608
609
610
611
612
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 602

def batch_project_app_test_case_update(parent, google_firebase_appdistro_v1alpha_batch_update_test_cases_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+parent}/testCases:batchUpdate', options)
  command.request_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaBatchUpdateTestCasesRequest::Representation
  command.request_object = google_firebase_appdistro_v1alpha_batch_update_test_cases_request_object
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaBatchUpdateTestCasesResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaBatchUpdateTestCasesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#cancel_project_app_release_test(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaCancelReleaseTestResponse

Abort automated test run on release.

Parameters:

  • name (String)

    Required. The name of the release test resource. Format: projects/ project_number/apps/app/releases/release/tests/test``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



422
423
424
425
426
427
428
429
430
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 422

def cancel_project_app_release_test(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}:cancel', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaCancelReleaseTestResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaCancelReleaseTestResponse
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#clear_project_app_test_case_test_case_cache(test_case, google_firebase_appdistro_v1alpha_clear_test_case_cache_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaClearTestCaseCacheResponse

Clears cached test runs for a specific test case and device(s).

Parameters:

  • test_case (String)

    Required. The name of the test case resource for which to clear the cache. Format: projects/project_number/apps/app/testCases/test_case``

  • google_firebase_appdistro_v1alpha_clear_test_case_cache_request_object (Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaClearTestCaseCacheRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



636
637
638
639
640
641
642
643
644
645
646
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 636

def clear_project_app_test_case_test_case_cache(test_case, google_firebase_appdistro_v1alpha_clear_test_case_cache_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+testCase}:clearTestCaseCache', options)
  command.request_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaClearTestCaseCacheRequest::Representation
  command.request_object = google_firebase_appdistro_v1alpha_clear_test_case_cache_request_object
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaClearTestCaseCacheResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaClearTestCaseCacheResponse
  command.params['testCase'] = test_case unless test_case.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_app_release_note(mobilesdk_app_id, release_id, google_firebase_appdistro_v1alpha_create_release_notes_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaCreateReleaseNotesResponse

Create release notes on a release.

Parameters:

  • mobilesdk_app_id (String)

    Required. Unique id for a Firebase app of the format: version: project_number:platform:hash(bundle_id) Example: 1:581234567376:android: aa0a3c7b135e90289

  • release_id (String)

    Required. Release identifier

  • google_firebase_appdistro_v1alpha_create_release_notes_request_object (Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaCreateReleaseNotesRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 219

def create_app_release_note(mobilesdk_app_id, release_id, google_firebase_appdistro_v1alpha_create_release_notes_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/apps/{mobilesdkAppId}/releases/{releaseId}/notes', options)
  command.request_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaCreateReleaseNotesRequest::Representation
  command.request_object = google_firebase_appdistro_v1alpha_create_release_notes_request_object
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaCreateReleaseNotesResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaCreateReleaseNotesResponse
  command.params['mobilesdkAppId'] = mobilesdk_app_id unless mobilesdk_app_id.nil?
  command.params['releaseId'] = release_id unless release_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_project_app_release_test(parent, google_firebase_appdistro_v1alpha_release_test_object = nil, release_test_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaReleaseTest

Run automated test(s) on release.

Parameters:

  • parent (String)

    Required. The name of the release resource, which is the parent of the test Format: projects/project_number/apps/app/releases/release``

  • google_firebase_appdistro_v1alpha_release_test_object (Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaReleaseTest) (defaults to: nil)
  • release_test_id (String) (defaults to: nil)

    Optional. The ID to use for the test, which will become the final component of the test's resource name. This value should be 4-63 characters, and valid characters are /a-z-/. If it is not provided one will be automatically generated.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



459
460
461
462
463
464
465
466
467
468
469
470
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 459

def create_project_app_release_test(parent, google_firebase_appdistro_v1alpha_release_test_object = nil, release_test_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+parent}/tests', options)
  command.request_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaReleaseTest::Representation
  command.request_object = google_firebase_appdistro_v1alpha_release_test_object
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaReleaseTest::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaReleaseTest
  command.params['parent'] = parent unless parent.nil?
  command.query['releaseTestId'] = release_test_id unless release_test_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_project_app_test_case(parent, google_firebase_appdistro_v1alpha_test_case_object = nil, test_case_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase

Create a new test case.

Parameters:

  • parent (String)

    Required. The parent resource where this test case will be created. Format: projects/project_number/apps/app``

  • google_firebase_appdistro_v1alpha_test_case_object (Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase) (defaults to: nil)
  • test_case_id (String) (defaults to: nil)

    Optional. The ID to use for the test case, which will become the final component of the test case's resource name. This value should be 4-63 characters, and valid characters are /a-z-/.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



674
675
676
677
678
679
680
681
682
683
684
685
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 674

def create_project_app_test_case(parent, google_firebase_appdistro_v1alpha_test_case_object = nil, test_case_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/{+parent}/testCases', options)
  command.request_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase::Representation
  command.request_object = google_firebase_appdistro_v1alpha_test_case_object
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase
  command.params['parent'] = parent unless parent.nil?
  command.query['testCaseId'] = test_case_id unless test_case_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_app_test_case(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleProtobufEmpty

Delete a test case.

Parameters:

  • name (String)

    Required. The name of the test case resource to delete. Format: projects/ project_number/apps/app/testCases/test_case``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



708
709
710
711
712
713
714
715
716
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 708

def delete_project_app_test_case(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:delete, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleProtobufEmpty::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleProtobufEmpty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#enable_app_release_access(mobilesdk_app_id, release_id, google_firebase_appdistro_v1alpha_enable_access_on_release_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaEnableAccessOnReleaseResponse

Enable access on a release for testers.

Parameters:

  • mobilesdk_app_id (String)

    Required. Unique id for a Firebase app of the format: version: project_number:platform:hash(bundle_id) Example: 1:581234567376:android: aa0a3c7b135e90289

  • release_id (String)

    Required. Release identifier

  • google_firebase_appdistro_v1alpha_enable_access_on_release_request_object (Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaEnableAccessOnReleaseRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 181

def enable_app_release_access(mobilesdk_app_id, release_id, google_firebase_appdistro_v1alpha_enable_access_on_release_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:post, 'v1alpha/apps/{mobilesdkAppId}/releases/{releaseId}/enable_access', options)
  command.request_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaEnableAccessOnReleaseRequest::Representation
  command.request_object = google_firebase_appdistro_v1alpha_enable_access_on_release_request_object
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaEnableAccessOnReleaseResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaEnableAccessOnReleaseResponse
  command.params['mobilesdkAppId'] = mobilesdk_app_id unless mobilesdk_app_id.nil?
  command.params['releaseId'] = release_id unless release_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_app(mobilesdk_app_id, app_view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaApp

Get the app, if it exists

Parameters:

  • mobilesdk_app_id (String)

    Unique id for a Firebase app of the format: version:project_number: platform:hash(bundle_id) Example: 1:581234567376:android:aa0a3c7b135e90289

  • app_view (String) (defaults to: nil)

    App view. When unset or set to BASIC, returns an App with everything set except for aab_state. When set to FULL, returns an App with aab_state set.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



78
79
80
81
82
83
84
85
86
87
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 78

def get_app(mobilesdk_app_id, app_view: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/apps/{mobilesdkAppId}', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaApp::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaApp
  command.params['mobilesdkAppId'] = mobilesdk_app_id unless mobilesdk_app_id.nil?
  command.query['appView'] = app_view unless app_view.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_app_jwt(mobilesdk_app_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaJwt

Get a JWT token

Parameters:

  • mobilesdk_app_id (String)

    Required. Unique id for a Firebase app of the format: version: project_number:platform:hash(bundle_id) Example: 1:581234567376:android: aa0a3c7b135e90289

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



111
112
113
114
115
116
117
118
119
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 111

def get_app_jwt(mobilesdk_app_id, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/apps/{mobilesdkAppId}/jwt', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaJwt::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaJwt
  command.params['mobilesdkAppId'] = mobilesdk_app_id unless mobilesdk_app_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_app_release_by_hash(mobilesdk_app_id, upload_hash, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetReleaseByUploadHashResponse

GET Release by binary upload hash

Parameters:

  • mobilesdk_app_id (String)

    Required. Unique id for a Firebase app of the format: version: project_number:platform:hash(bundle_id) Example: 1:581234567376:android: aa0a3c7b135e90289

  • upload_hash (String)

    Required. The hash for the upload

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



145
146
147
148
149
150
151
152
153
154
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 145

def get_app_release_by_hash(mobilesdk_app_id, upload_hash, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/apps/{mobilesdkAppId}/release_by_hash/{uploadHash}', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetReleaseByUploadHashResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetReleaseByUploadHashResponse
  command.params['mobilesdkAppId'] = mobilesdk_app_id unless mobilesdk_app_id.nil?
  command.params['uploadHash'] = upload_hash unless upload_hash.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_app_tester_tester_udids(mobilesdk_app_id, project: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetTesterUdidsResponse

Get UDIDs of tester iOS devices in a project

Parameters:

  • mobilesdk_app_id (String)

    Unique id for a Firebase app of the format: version:project_number: platform:hash(bundle_id) Example: 1:581234567376:android:aa0a3c7b135e90289

  • project (String) (defaults to: nil)

    The name of the project, which is the parent of testers Format: projects/ project_number``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



256
257
258
259
260
261
262
263
264
265
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 256

def get_app_tester_tester_udids(mobilesdk_app_id, project: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/apps/{mobilesdkAppId}/testers:getTesterUdids', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetTesterUdidsResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetTesterUdidsResponse
  command.params['mobilesdkAppId'] = mobilesdk_app_id unless mobilesdk_app_id.nil?
  command.query['project'] = project unless project.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_app_upload_status(mobilesdk_app_id, upload_token, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetUploadStatusResponse

GET Binary upload status by token

Parameters:

  • mobilesdk_app_id (String)

    Required. Unique id for a Firebase app of the format: version: project_number:platform:hash(bundle_id) Example: 1:581234567376:android: aa0a3c7b135e90289

  • upload_token (String)

    Required. The token for the upload

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



291
292
293
294
295
296
297
298
299
300
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 291

def get_app_upload_status(mobilesdk_app_id, upload_token, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/apps/{mobilesdkAppId}/upload_status/{uploadToken}', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetUploadStatusResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetUploadStatusResponse
  command.params['mobilesdkAppId'] = mobilesdk_app_id unless mobilesdk_app_id.nil?
  command.params['uploadToken'] = upload_token unless upload_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_app_release_test(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaReleaseTest

Get results for automated test run on release.

Parameters:

  • name (String)

    Required. The name of the release test resource. Format: projects/ project_number/apps/app/releases/release/tests/test``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



493
494
495
496
497
498
499
500
501
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 493

def get_project_app_release_test(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaReleaseTest::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaReleaseTest
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_app_test_case(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase

Get a test case.

Parameters:

  • name (String)

    Required. The name of the test case resource to retrieve. Format: projects/ project_number/apps/app/testCases/test_case``

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



739
740
741
742
743
744
745
746
747
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 739

def get_project_app_test_case(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_app_test_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestConfig

Gets configuration for automated tests.

Parameters:

  • name (String)

    Required. The name of the TestConfig resource to retrieve. Format: projects/ project_number/apps/app/testConfig

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



354
355
356
357
358
359
360
361
362
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 354

def get_project_app_test_config(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestConfig::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestConfig
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_test_quota(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestQuota

Get information about the quota for ReleaseTests.

Parameters:

  • name (String)

    Required. The name of the TestQuota resource to retrieve. Format: projects/ project_number/testQuota

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



323
324
325
326
327
328
329
330
331
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 323

def get_project_test_quota(name, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+name}', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestQuota::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestQuota
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_tester_udids(project, mobilesdk_app_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetTesterUdidsResponse

Get UDIDs of tester iOS devices in a project

Parameters:

  • project (String)

    The name of the project, which is the parent of testers Format: projects/ project_number``

  • mobilesdk_app_id (String) (defaults to: nil)

    Unique id for a Firebase app of the format: version:project_number: platform:hash(bundle_id) Example: 1:581234567376:android:aa0a3c7b135e90289

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



852
853
854
855
856
857
858
859
860
861
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 852

def get_project_tester_udids(project, mobilesdk_app_id: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+project}/testers:udids', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetTesterUdidsResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetTesterUdidsResponse
  command.params['project'] = project unless project.nil?
  command.query['mobilesdkAppId'] = mobilesdk_app_id unless mobilesdk_app_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_app_release_tests(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaListReleaseTestsResponse

List results for automated tests run on release.

Parameters:

  • parent (String)

    Required. The name of the release resource, which is the parent of the tests Format: projects/project_number/apps/app/releases/release``

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of tests to return. The service may return fewer than this value.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListReleaseTests call. Provide this to retrieve the subsequent page.

  • view (String) (defaults to: nil)

    Optional. The requested view on the returned ReleaseTests. Defaults to the basic view.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 533

def list_project_app_release_tests(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/tests', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaListReleaseTestsResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaListReleaseTestsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['view'] = view unless view.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_app_test_cases(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaListTestCasesResponse

List test cases.

Parameters:

  • parent (String)

    Required. The parent resource from which to list test cases. Format: projects/ project_number/apps/app``

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of test cases to return. The service may return fewer than this value. If unspecified, at most 50 test cases will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

  • page_token (String) (defaults to: nil)

    Optional. A page token, received from a previous ListTestCases call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListTestCases must match the call that provided the page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



778
779
780
781
782
783
784
785
786
787
788
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 778

def list_project_app_test_cases(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:get, 'v1alpha/{+parent}/testCases', options)
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaListTestCasesResponse::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaListTestCasesResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_project_app_test_case(name, google_firebase_appdistro_v1alpha_test_case_object = nil, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase

Update a test case.

Parameters:

  • name (String)

    Identifier. The name of the test case resource. Format: projects/ project_number/apps/app/testCases/test_case``

  • google_firebase_appdistro_v1alpha_test_case_object (Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase) (defaults to: nil)
  • allow_missing (Boolean) (defaults to: nil)

    Optional. If set to true, and the test case is not found, a new test case will be created.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



815
816
817
818
819
820
821
822
823
824
825
826
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 815

def patch_project_app_test_case(name, google_firebase_appdistro_v1alpha_test_case_object = nil, allow_missing: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1alpha/{+name}', options)
  command.request_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase::Representation
  command.request_object = google_firebase_appdistro_v1alpha_test_case_object
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase
  command.params['name'] = name unless name.nil?
  command.query['allowMissing'] = allow_missing unless allow_missing.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#update_project_app_test_config(name, google_firebase_appdistro_v1alpha_test_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestConfig

Updates automated test configuration.

Parameters:

  • name (String)

    Identifier. The name of the test configuration resource. Format: projects/ project_number/apps/app/testConfig

  • google_firebase_appdistro_v1alpha_test_config_object (Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestConfig) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    Optional. The list of fields to update.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:

  • (Google::Apis::ServerError)

    An error occurred on the server and the request can be retried

  • (Google::Apis::ClientError)

    The request is invalid and should not be retried without modification

  • (Google::Apis::AuthorizationError)

    Authorization is required



388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/google/apis/firebaseappdistribution_v1alpha/service.rb', line 388

def update_project_app_test_config(name, google_firebase_appdistro_v1alpha_test_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command = make_simple_command(:patch, 'v1alpha/{+name}', options)
  command.request_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestConfig::Representation
  command.request_object = google_firebase_appdistro_v1alpha_test_config_object
  command.response_representation = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestConfig::Representation
  command.response_class = Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestConfig
  command.params['name'] = name unless name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end