Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1Release

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

A release of a Firebase app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1Release

Returns a new instance of GoogleFirebaseAppdistroV1Release.



154
155
156
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#android_package_registration_stateString

Output only. Registration state of the Android package (BinaryType.APK). Corresponds to the JSON property androidPackageRegistrationState

Returns:

  • (String)


94
95
96
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 94

def android_package_registration_state
  @android_package_registration_state
end

#binary_download_uriString

Output only. A signed link (which expires in one hour) to directly download the app binary (IPA/APK/AAB) file. Corresponds to the JSON property binaryDownloadUri

Returns:

  • (String)


100
101
102
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 100

def binary_download_uri
  @binary_download_uri
end

#build_versionString

Output only. Build version of the release. For an Android release, the build version is the versionCode. For an iOS release, the build version is the CFBundleVersion. Corresponds to the JSON property buildVersion

Returns:

  • (String)


107
108
109
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 107

def build_version
  @build_version
end

#create_timeString

Output only. The time the release was created. Corresponds to the JSON property createTime

Returns:

  • (String)


112
113
114
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 112

def create_time
  @create_time
end

#display_versionString

Output only. Display version of the release. For an Android release, the display version is the versionName. For an iOS release, the display version is the CFBundleShortVersionString. Corresponds to the JSON property displayVersion

Returns:

  • (String)


119
120
121
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 119

def display_version
  @display_version
end

#expire_timeString

Output only. The time the release will expire. Corresponds to the JSON property expireTime

Returns:

  • (String)


124
125
126
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 124

def expire_time
  @expire_time
end

#firebase_console_uriString

Output only. A link to the Firebase console displaying a single release. Corresponds to the JSON property firebaseConsoleUri

Returns:

  • (String)


129
130
131
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 129

def firebase_console_uri
  @firebase_console_uri
end

#nameString

The name of the release resource. Format: projects/project_number/apps/app /releases/release` Corresponds to the JSON propertyname`

Returns:

  • (String)


135
136
137
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 135

def name
  @name
end

#release_notesGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1ReleaseNotes

Notes that belong to a release. Corresponds to the JSON property releaseNotes



140
141
142
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 140

def release_notes
  @release_notes
end

#testing_uriString

Output only. A link to the release in the tester web clip or Android app that lets testers (which were granted access to the app) view release notes and install the app onto their devices. Corresponds to the JSON property testingUri

Returns:

  • (String)


147
148
149
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 147

def testing_uri
  @testing_uri
end

#update_timeString

Output only. The time the release was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


152
153
154
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 152

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 159

def update!(**args)
  @android_package_registration_state = args[:android_package_registration_state] if args.key?(:android_package_registration_state)
  @binary_download_uri = args[:binary_download_uri] if args.key?(:binary_download_uri)
  @build_version = args[:build_version] if args.key?(:build_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_version = args[:display_version] if args.key?(:display_version)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @firebase_console_uri = args[:firebase_console_uri] if args.key?(:firebase_console_uri)
  @name = args[:name] if args.key?(:name)
  @release_notes = args[:release_notes] if args.key?(:release_notes)
  @testing_uri = args[:testing_uri] if args.key?(:testing_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end