Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaAabCertificate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

App bundle test certificate

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaAabCertificate

Returns a new instance of GoogleFirebaseAppdistroV1alphaAabCertificate.



250
251
252
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_hash_md5String

MD5 hash of the certificate used to resign the AAB Corresponds to the JSON property certificateHashMd5

Returns:

  • (String)


238
239
240
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 238

def certificate_hash_md5
  @certificate_hash_md5
end

#certificate_hash_sha1String

SHA1 hash of the certificate used to resign the AAB Corresponds to the JSON property certificateHashSha1

Returns:

  • (String)


243
244
245
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 243

def certificate_hash_sha1
  @certificate_hash_sha1
end

#certificate_hash_sha256String

SHA256 hash of the certificate used to resign the AAB Corresponds to the JSON property certificateHashSha256

Returns:

  • (String)


248
249
250
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 248

def certificate_hash_sha256
  @certificate_hash_sha256
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



255
256
257
258
259
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 255

def update!(**args)
  @certificate_hash_md5 = args[:certificate_hash_md5] if args.key?(:certificate_hash_md5)
  @certificate_hash_sha1 = args[:certificate_hash_sha1] if args.key?(:certificate_hash_sha1)
  @certificate_hash_sha256 = args[:certificate_hash_sha256] if args.key?(:certificate_hash_sha256)
end