Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaApp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

An app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaApp

Returns a new instance of GoogleFirebaseAppdistroV1alphaApp.



408
409
410
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aab_certificateGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaAabCertificate

App bundle test certificate Corresponds to the JSON property aabCertificate



374
375
376
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 374

def aab_certificate
  @aab_certificate
end

#aab_stateString

App bundle state. Only valid for android apps. The app_view field in the request must be set to FULL in order for this to be populated. Corresponds to the JSON property aabState

Returns:

  • (String)


380
381
382
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 380

def aab_state
  @aab_state
end

#app_idString

Firebase gmp app id Corresponds to the JSON property appId

Returns:

  • (String)


385
386
387
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 385

def app_id
  @app_id
end

#bundle_idString

Bundle identifier Corresponds to the JSON property bundleId

Returns:

  • (String)


390
391
392
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 390

def bundle_id
  @bundle_id
end

#contact_emailString

Developer contact email for testers to reach out to about privacy or support issues. Corresponds to the JSON property contactEmail

Returns:

  • (String)


396
397
398
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 396

def contact_email
  @contact_email
end

#platformString

iOS or Android Corresponds to the JSON property platform

Returns:

  • (String)


401
402
403
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 401

def platform
  @platform
end

#project_numberString

Project number of the Firebase project, for example 300830567303. Corresponds to the JSON property projectNumber

Returns:

  • (String)


406
407
408
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 406

def project_number
  @project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



413
414
415
416
417
418
419
420
421
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 413

def update!(**args)
  @aab_certificate = args[:aab_certificate] if args.key?(:aab_certificate)
  @aab_state = args[:aab_state] if args.key?(:aab_state)
  @app_id = args[:app_id] if args.key?(:app_id)
  @bundle_id = args[:bundle_id] if args.key?(:bundle_id)
  @contact_email = args[:contact_email] if args.key?(:contact_email)
  @platform = args[:platform] if args.key?(:platform)
  @project_number = args[:project_number] if args.key?(:project_number)
end