Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

A high level action taken by the AI on the device, potentially involving multiple taps, text entries, waits, etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaDeviceAction

Returns a new instance of GoogleFirebaseAppdistroV1alphaDeviceAction.



636
637
638
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. A short description of the high level action taken by the AI agent. Corresponds to the JSON property description

Returns:

  • (String)


628
629
630
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 628

def description
  @description
end

#device_interactionsArray<Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteraction>

Output only. The interactions made with the device as part of this higher level action taken by the agent, such as taps, text entries, waits, etc. Corresponds to the JSON property deviceInteractions



634
635
636
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 634

def device_interactions
  @device_interactions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



641
642
643
644
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 641

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @device_interactions = args[:device_interactions] if args.key?(:device_interactions)
end