Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteraction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

An interaction with the device, such as a tap, text entry, wait, etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaDeviceInteraction

Returns a new instance of GoogleFirebaseAppdistroV1alphaDeviceInteraction.



831
832
833
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#back_actionGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteractionBack

A back action. Corresponds to the JSON property backAction



768
769
770
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 768

def back_action
  @back_action
end

#drag_and_dropGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteractionDragAndDrop

A drag and drop action. Corresponds to the JSON property dragAndDrop



773
774
775
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 773

def drag_and_drop
  @drag_and_drop
end

#enter_textGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteractionEnterText

A text entry action, that enters text into a particular text field, clearing any existing text in the field. Corresponds to the JSON property enterText



779
780
781
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 779

def enter_text
  @enter_text
end

#key_codeString

Output only. Key code for a key event action. Corresponds to the JSON property keyCode

Returns:

  • (String)


784
785
786
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 784

def key_code
  @key_code
end

#long_pressGoogle::Apis::FirebaseappdistributionV1alpha::AndroidxCrawlerOutputPoint

Point for describing bounding boxes tap locations Top left is 0,0 Corresponds to the JSON property longPress



789
790
791
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 789

def long_press
  @long_press
end

#screenshotGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaScreenshot

A device screenshot taken during a test. Corresponds to the JSON property screenshot



794
795
796
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 794

def screenshot
  @screenshot
end

#swipeGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteractionSwipe

A swipe action. Corresponds to the JSON property swipe



799
800
801
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 799

def swipe
  @swipe
end

#tap_propGoogle::Apis::FirebaseappdistributionV1alpha::AndroidxCrawlerOutputPoint

Point for describing bounding boxes tap locations Top left is 0,0 Corresponds to the JSON property tap



804
805
806
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 804

def tap_prop
  @tap_prop
end

#target_folded_stateString

Output only. The target folded state of the device in a set folded state action. The valid string values are device-dependent, and can be found using adb shell cmd device_state print-states. Corresponds to the JSON property targetFoldedState

Returns:

  • (String)


811
812
813
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 811

def target_folded_state
  @target_folded_state
end

#target_orientationString

Output only. The target orientation of the device in a set orientation action. Corresponds to the JSON property targetOrientation

Returns:

  • (String)


816
817
818
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 816

def target_orientation
  @target_orientation
end

#text_inputString

Output only. A text input action, that types some text into whatever field is currently focused, if any. Unlike enter_text this action requires that the field be brought into focus first, for example by emitting a tap action before this one. Corresponds to the JSON property textInput

Returns:

  • (String)


824
825
826
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 824

def text_input
  @text_input
end

#waitGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteractionWait

A wait action. Corresponds to the JSON property wait



829
830
831
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 829

def wait
  @wait
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



836
837
838
839
840
841
842
843
844
845
846
847
848
849
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 836

def update!(**args)
  @back_action = args[:back_action] if args.key?(:back_action)
  @drag_and_drop = args[:drag_and_drop] if args.key?(:drag_and_drop)
  @enter_text = args[:enter_text] if args.key?(:enter_text)
  @key_code = args[:key_code] if args.key?(:key_code)
  @long_press = args[:long_press] if args.key?(:long_press)
  @screenshot = args[:screenshot] if args.key?(:screenshot)
  @swipe = args[:swipe] if args.key?(:swipe)
  @tap_prop = args[:tap_prop] if args.key?(:tap_prop)
  @target_folded_state = args[:target_folded_state] if args.key?(:target_folded_state)
  @target_orientation = args[:target_orientation] if args.key?(:target_orientation)
  @text_input = args[:text_input] if args.key?(:text_input)
  @wait = args[:wait] if args.key?(:wait)
end