Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteractionEnterText

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

A text entry action, that enters text into a particular text field, clearing any existing text in the field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaDeviceInteractionEnterText

Returns a new instance of GoogleFirebaseAppdistroV1alphaDeviceInteractionEnterText.



911
912
913
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 911

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#element_boundsGoogle::Apis::FirebaseappdistributionV1alpha::AndroidxCrawlerOutputRectangle

Rectangle for describing bounding boxes Corresponds to the JSON property elementBounds



904
905
906
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 904

def element_bounds
  @element_bounds
end

#textString

Output only. The text to enter. Corresponds to the JSON property text

Returns:

  • (String)


909
910
911
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 909

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



916
917
918
919
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 916

def update!(**args)
  @element_bounds = args[:element_bounds] if args.key?(:element_bounds)
  @text = args[:text] if args.key?(:text)
end