Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteractionSwipe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

A swipe action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaDeviceInteractionSwipe

Returns a new instance of GoogleFirebaseAppdistroV1alphaDeviceInteractionSwipe.



930
931
932
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 930

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endGoogle::Apis::FirebaseappdistributionV1alpha::AndroidxCrawlerOutputPoint

Point for describing bounding boxes tap locations Top left is 0,0 Corresponds to the JSON property end



923
924
925
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 923

def end
  @end
end

#startGoogle::Apis::FirebaseappdistributionV1alpha::AndroidxCrawlerOutputPoint

Point for describing bounding boxes tap locations Top left is 0,0 Corresponds to the JSON property start



928
929
930
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 928

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



935
936
937
938
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 935

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @start = args[:start] if args.key?(:start)
end