Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaEnableAccessOnReleaseRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

The request message for EnableAccessOnRelease.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaEnableAccessOnReleaseRequest

Returns a new instance of GoogleFirebaseAppdistroV1alphaEnableAccessOnReleaseRequest.



995
996
997
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_versionString

Optional. Ignored. Used to be build version of the app release if an instance identifier was provided for the release_id. Corresponds to the JSON property buildVersion

Returns:

  • (String)


974
975
976
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 974

def build_version
  @build_version
end

#display_versionString

Optional. Ignored. Used to be display version of the app release if an instance identifier was provided for the release_id. Corresponds to the JSON property displayVersion

Returns:

  • (String)


980
981
982
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 980

def display_version
  @display_version
end

#emailsArray<String>

Optional. An email address which should get access to this release, for example rebeccahe@google.com Corresponds to the JSON property emails

Returns:

  • (Array<String>)


986
987
988
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 986

def emails
  @emails
end

#group_idsArray<String>

Optional. A repeated list of group aliases to enable access to a release for Note: This field is misnamed, but can't be changed because we need to maintain compatibility with old build tools Corresponds to the JSON property groupIds

Returns:

  • (Array<String>)


993
994
995
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 993

def group_ids
  @group_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1000
1001
1002
1003
1004
1005
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1000

def update!(**args)
  @build_version = args[:build_version] if args.key?(:build_version)
  @display_version = args[:display_version] if args.key?(:display_version)
  @emails = args[:emails] if args.key?(:emails)
  @group_ids = args[:group_ids] if args.key?(:group_ids)
end