Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetReleaseByUploadHashResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

Response object to get the release given a upload hash

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaGetReleaseByUploadHashResponse

Returns a new instance of GoogleFirebaseAppdistroV1alphaGetReleaseByUploadHashResponse.



1024
1025
1026
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#releaseGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaRelease

Proto defining a release object Corresponds to the JSON property release



1022
1023
1024
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1022

def release
  @release
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1029
1030
1031
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1029

def update!(**args)
  @release = args[:release] if args.key?(:release)
end