Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGetUploadStatusResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

The response message for GetUploadStatus.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaGetUploadStatusResponse

Returns a new instance of GoogleFirebaseAppdistroV1alphaGetUploadStatusResponse.



1078
1079
1080
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeString

The error code associated with (only set on "FAILURE") Corresponds to the JSON property errorCode

Returns:

  • (String)


1060
1061
1062
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1060

def error_code
  @error_code
end

#messageString

Any additional context for the given upload status (e.g. error message) Meant to be displayed to the client Corresponds to the JSON property message

Returns:

  • (String)


1066
1067
1068
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1066

def message
  @message
end

#releaseGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaRelease

Proto defining a release object Corresponds to the JSON property release



1071
1072
1073
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1071

def release
  @release
end

#statusString

The status of the upload Corresponds to the JSON property status

Returns:

  • (String)


1076
1077
1078
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1076

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1083
1084
1085
1086
1087
1088
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1083

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @message = args[:message] if args.key?(:message)
  @release = args[:release] if args.key?(:release)
  @status = args[:status] if args.key?(:status)
end