Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb
Overview
Information to help the customer understand why the agent took this action.
Instance Attribute Summary collapse
-
#annotated_screenshot_uri ⇒ String
Output only.
-
#json_uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo
constructor
A new instance of GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo
Returns a new instance of GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo.
1162 1163 1164 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotated_screenshot_uri ⇒ String
Output only. URI of the screenshot with elements labeled which was used by the
agent.
Corresponds to the JSON property annotatedScreenshotUri
1155 1156 1157 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1155 def annotated_screenshot_uri @annotated_screenshot_uri end |
#json_uri ⇒ String
Output only. Structured data explaining the agent's choice.
Corresponds to the JSON property jsonUri
1160 1161 1162 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1160 def json_uri @json_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1167 1168 1169 1170 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1167 def update!(**args) @annotated_screenshot_uri = args[:annotated_screenshot_uri] if args.key?(:annotated_screenshot_uri) @json_uri = args[:json_uri] if args.key?(:json_uri) end |