Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaRelease

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

Proto defining a release object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaRelease

Returns a new instance of GoogleFirebaseAppdistroV1alphaRelease.



1386
1387
1388
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1386

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#build_versionString

Release build version Corresponds to the JSON property buildVersion

Returns:

  • (String)


1334
1335
1336
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1334

def build_version
  @build_version
end

#display_versionString

Release version Corresponds to the JSON property displayVersion

Returns:

  • (String)


1339
1340
1341
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1339

def display_version
  @display_version
end

#distributed_atString

Timestamp when the release was created Corresponds to the JSON property distributedAt

Returns:

  • (String)


1344
1345
1346
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1344

def distributed_at
  @distributed_at
end

#idString

Release Id Corresponds to the JSON property id

Returns:

  • (String)


1349
1350
1351
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1349

def id
  @id
end

#instance_idString

Instance id of the release Corresponds to the JSON property instanceId

Returns:

  • (String)


1354
1355
1356
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1354

def instance_id
  @instance_id
end

#last_activity_atString

Last activity timestamp Corresponds to the JSON property lastActivityAt

Returns:

  • (String)


1359
1360
1361
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1359

def last_activity_at
  @last_activity_at
end

#open_invitation_countFixnum

Number of testers who have open invitations for the release Corresponds to the JSON property openInvitationCount

Returns:

  • (Fixnum)


1364
1365
1366
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1364

def open_invitation_count
  @open_invitation_count
end

#received_atString

unused. Corresponds to the JSON property receivedAt

Returns:

  • (String)


1369
1370
1371
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1369

def received_at
  @received_at
end

#release_notes_summaryString

Release notes summary Corresponds to the JSON property releaseNotesSummary

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1374

def release_notes_summary
  @release_notes_summary
end

#tester_countFixnum

Count of testers added to the release Corresponds to the JSON property testerCount

Returns:

  • (Fixnum)


1379
1380
1381
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1379

def tester_count
  @tester_count
end

#tester_with_install_countFixnum

Number of testers who have installed the release Corresponds to the JSON property testerWithInstallCount

Returns:

  • (Fixnum)


1384
1385
1386
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1384

def tester_with_install_count
  @tester_with_install_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1391

def update!(**args)
  @build_version = args[:build_version] if args.key?(:build_version)
  @display_version = args[:display_version] if args.key?(:display_version)
  @distributed_at = args[:distributed_at] if args.key?(:distributed_at)
  @id = args[:id] if args.key?(:id)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @last_activity_at = args[:last_activity_at] if args.key?(:last_activity_at)
  @open_invitation_count = args[:open_invitation_count] if args.key?(:open_invitation_count)
  @received_at = args[:received_at] if args.key?(:received_at)
  @release_notes_summary = args[:release_notes_summary] if args.key?(:release_notes_summary)
  @tester_count = args[:tester_count] if args.key?(:tester_count)
  @tester_with_install_count = args[:tester_with_install_count] if args.key?(:tester_with_install_count)
end