Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaReleaseTest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

Instance of an automated test for a release.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaReleaseTest

Returns a new instance of GoogleFirebaseAppdistroV1alphaReleaseTest.



1473
1474
1475
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_instructionsGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaAiInstructions

Optional. Instructions for AI driven test. Corresponds to the JSON property aiInstructions



1432
1433
1434
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1432

def ai_instructions
  @ai_instructions
end

#create_timeString

Output only. Timestamp when the test was run. Corresponds to the JSON property createTime

Returns:

  • (String)


1437
1438
1439
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1437

def create_time
  @create_time
end

#device_executionsArray<Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceExecution>

Required. The results of the test on each device. Corresponds to the JSON property deviceExecutions



1442
1443
1444
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1442

def device_executions
  @device_executions
end

#display_nameString

Optional. Display name of the release test. Required if the release test is created with multiple goals. Corresponds to the JSON property displayName

Returns:

  • (String)


1448
1449
1450
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1448

def display_name
  @display_name
end

#login_credentialGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaLoginCredential

Login credential for automated tests Corresponds to the JSON property loginCredential



1453
1454
1455
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1453

def 
  @login_credential
end

#nameString

The name of the release test resource. Format: projects/project_number/apps/ app/releases/release/tests/test` Corresponds to the JSON propertyname`

Returns:

  • (String)


1459
1460
1461
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1459

def name
  @name
end

#test_caseString

Optional. The test case that was used to generate this release test. Note: The test case may have changed or been deleted since the release test was created. Format: projects/project_number/apps/app/testCases/test_case` Corresponds to the JSON propertytestCase`

Returns:

  • (String)


1466
1467
1468
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1466

def test_case
  @test_case
end

#test_stateString

Output only. The state of the release test. Corresponds to the JSON property testState

Returns:

  • (String)


1471
1472
1473
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1471

def test_state
  @test_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1478

def update!(**args)
  @ai_instructions = args[:ai_instructions] if args.key?(:ai_instructions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @device_executions = args[:device_executions] if args.key?(:device_executions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @login_credential = args[:login_credential] if args.key?(:login_credential)
  @name = args[:name] if args.key?(:name)
  @test_case = args[:test_case] if args.key?(:test_case)
  @test_state = args[:test_state] if args.key?(:test_state)
end