Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb
Overview
AI test cases
Instance Attribute Summary collapse
-
#ai_instructions ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaAiInstructions
Optional.
-
#create_time ⇒ String
Output only.
-
#dependent_test_cases ⇒ Array<String>
Output only.
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#prerequisite_test_case ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaTestCase
constructor
A new instance of GoogleFirebaseAppdistroV1alphaTestCase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaTestCase
Returns a new instance of GoogleFirebaseAppdistroV1alphaTestCase.
1652 1653 1654 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ai_instructions ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaAiInstructions
Optional. Instructions for AI driven test.
Corresponds to the JSON property aiInstructions
1624 1625 1626 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1624 def ai_instructions @ai_instructions end |
#create_time ⇒ String
Output only. Timestamp when the test case was created
Corresponds to the JSON property createTime
1629 1630 1631 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1629 def create_time @create_time end |
#dependent_test_cases ⇒ Array<String>
Output only. Other test cases that depend on this test case as a prerequisite.
Corresponds to the JSON property dependentTestCases
1634 1635 1636 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1634 def dependent_test_cases @dependent_test_cases end |
#display_name ⇒ String
Required. Display name of the test case.
Corresponds to the JSON property displayName
1639 1640 1641 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1639 def display_name @display_name end |
#name ⇒ String
Identifier. The name of the test case resource. Format: projects/
project_number/apps/app/testCases/test_case`
Corresponds to the JSON propertyname`
1645 1646 1647 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1645 def name @name end |
#prerequisite_test_case ⇒ String
Optional. Test case that must be run before this test case.
Corresponds to the JSON property prerequisiteTestCase
1650 1651 1652 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1650 def prerequisite_test_case @prerequisite_test_case end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1657 1658 1659 1660 1661 1662 1663 1664 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1657 def update!(**args) @ai_instructions = args[:ai_instructions] if args.key?(:ai_instructions) @create_time = args[:create_time] if args.key?(:create_time) @dependent_test_cases = args[:dependent_test_cases] if args.key?(:dependent_test_cases) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @prerequisite_test_case = args[:prerequisite_test_case] if args.key?(:prerequisite_test_case) end |