Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaUpdateTestCaseRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

The request message for UpdateTestCase.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaUpdateTestCaseRequest

Returns a new instance of GoogleFirebaseAppdistroV1alphaUpdateTestCaseRequest.



1833
1834
1835
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_missingBoolean Also known as: allow_missing?

Optional. If set to true, and the test case is not found, a new test case will be created. Corresponds to the JSON property allowMissing

Returns:

  • (Boolean)


1825
1826
1827
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1825

def allow_missing
  @allow_missing
end

#test_caseGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase

AI test cases Corresponds to the JSON property testCase



1831
1832
1833
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1831

def test_case
  @test_case
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1838
1839
1840
1841
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1838

def update!(**args)
  @allow_missing = args[:allow_missing] if args.key?(:allow_missing)
  @test_case = args[:test_case] if args.key?(:test_case)
end