Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaAiStep
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaAiStep
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb
Overview
A step to be accomplished by the AI
Instance Attribute Summary collapse
-
#assertion ⇒ String
An assertion to be checked by the AI Corresponds to the JSON property
assertion. -
#goal ⇒ String
A goal to be accomplished by the AI Corresponds to the JSON property
goal. -
#hint ⇒ String
Optional.
-
#success_criteria ⇒ String
Optional.
-
#test_case ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaAiStep
constructor
A new instance of GoogleFirebaseAppdistroV1alphaAiStep.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaAiStep
Returns a new instance of GoogleFirebaseAppdistroV1alphaAiStep.
310 311 312 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 310 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assertion ⇒ String
An assertion to be checked by the AI
Corresponds to the JSON property assertion
282 283 284 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 282 def assertion @assertion end |
#goal ⇒ String
A goal to be accomplished by the AI
Corresponds to the JSON property goal
287 288 289 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 287 def goal @goal end |
#hint ⇒ String
Optional. Hint text containing suggestions to help the agent accomplish the
goal
Corresponds to the JSON property hint
293 294 295 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 293 def hint @hint end |
#success_criteria ⇒ String
Optional. A visual description of the screen's expected state after the step
has been successfully completed. This is referred to as the "final screen
assertion" in the Firebase console and CLI tools. This field must be provided
for the last step in a test case, and is optional for all other steps.
Corresponds to the JSON property successCriteria
301 302 303 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 301 def success_criteria @success_criteria end |
#test_case ⇒ String
Output only. The test case that contained this step. Note: The test case may
have changed or been deleted since this step was created. Format: projects/
project_number/apps/app/testCases/test_case`
Corresponds to the JSON propertytestCase`
308 309 310 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 308 def test_case @test_case end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
315 316 317 318 319 320 321 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 315 def update!(**args) @assertion = args[:assertion] if args.key?(:assertion) @goal = args[:goal] if args.key?(:goal) @hint = args[:hint] if args.key?(:hint) @success_criteria = args[:success_criteria] if args.key?(:success_criteria) @test_case = args[:test_case] if args.key?(:test_case) end |