Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceExecution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

The results of running an automated test on a particular device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaDeviceExecution

Returns a new instance of GoogleFirebaseAppdistroV1alphaDeviceExecution.



736
737
738
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_step_resultsArray<Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaAiStepResult>

Output only. Results of the AI steps if passed in Corresponds to the JSON property aiStepResults



648
649
650
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 648

def ai_step_results
  @ai_step_results
end

#app_crashGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaAppCrash

An app crash that occurred during an automated test. Corresponds to the JSON property appCrash



653
654
655
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 653

def app_crash
  @app_crash
end

#crawl_graph_uriString

Output only. A URI to an image of the Robo crawl graph. Corresponds to the JSON property crawlGraphUri

Returns:

  • (String)


658
659
660
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 658

def crawl_graph_uri
  @crawl_graph_uri
end

#deviceGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestDevice

A device on which automated tests can be run. Corresponds to the JSON property device



663
664
665
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 663

def device
  @device
end

#execution_typeString

Output only. The type of execution for the test. Corresponds to the JSON property executionType

Returns:

  • (String)


668
669
670
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 668

def execution_type
  @execution_type
end

#failed_reasonString

Output only. The reason why the test failed. Corresponds to the JSON property failedReason

Returns:

  • (String)


673
674
675
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 673

def failed_reason
  @failed_reason
end

#final_ai_assertion_missingBoolean Also known as: final_ai_assertion_missing?

Output only. Indicates that the test replayed saved actions and concluded without a final AI assertion. Corresponds to the JSON property finalAiAssertionMissing

Returns:

  • (Boolean)


679
680
681
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 679

def final_ai_assertion_missing
  @final_ai_assertion_missing
end

#inconclusive_reasonString

Output only. The reason why the test was inconclusive. Corresponds to the JSON property inconclusiveReason

Returns:

  • (String)


685
686
687
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 685

def inconclusive_reason
  @inconclusive_reason
end

#nameString

Identifier. The name of the device execution resource. Format: projects/ project_number/apps/app/releases/release/tests/test/deviceExecutions/ device_execution` Corresponds to the JSON propertyname`

Returns:

  • (String)


692
693
694
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 692

def name
  @name
end

#origin_device_executionString

Output only. The device execution from which cached steps were used during this execution. Note: This field is only populated for ACTION_BASED_REPLAY executions. If the original device execution no longer exists, this field will be empty. Format: projects/project_number/apps/app/releases/release/ tests/test/deviceExecutions/device_execution` Corresponds to the JSON propertyoriginDeviceExecution`

Returns:

  • (String)


701
702
703
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 701

def origin_device_execution
  @origin_device_execution
end

#results_storage_pathString

Output only. The path to a directory in Cloud Storage that will eventually contain the results for this execution. For example, gs://bucket/Nexus5-18-en- portrait. Corresponds to the JSON property resultsStoragePath

Returns:

  • (String)


708
709
710
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 708

def results_storage_path
  @results_storage_path
end

#robo_statsGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaRoboStats

Statistics collected during a Robo test. Corresponds to the JSON property roboStats



713
714
715
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 713

def robo_stats
  @robo_stats
end

#screenshot_urisArray<String>

Output only. A list of screenshot image URIs taken from the Robo crawl. The file names are numbered by the order in which they were taken. Corresponds to the JSON property screenshotUris

Returns:

  • (Array<String>)


719
720
721
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 719

def screenshot_uris
  @screenshot_uris
end

#stateString

Output only. The state of the test. Corresponds to the JSON property state

Returns:

  • (String)


724
725
726
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 724

def state
  @state
end

#video_start_timeString

Output only. The time at which the video started recording. Corresponds to the JSON property videoStartTime

Returns:

  • (String)


729
730
731
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 729

def video_start_time
  @video_start_time
end

#video_uriString

Output only. A URI to a video of the test run. Corresponds to the JSON property videoUri

Returns:

  • (String)


734
735
736
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 734

def video_uri
  @video_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 741

def update!(**args)
  @ai_step_results = args[:ai_step_results] if args.key?(:ai_step_results)
  @app_crash = args[:app_crash] if args.key?(:app_crash)
  @crawl_graph_uri = args[:crawl_graph_uri] if args.key?(:crawl_graph_uri)
  @device = args[:device] if args.key?(:device)
  @execution_type = args[:execution_type] if args.key?(:execution_type)
  @failed_reason = args[:failed_reason] if args.key?(:failed_reason)
  @final_ai_assertion_missing = args[:final_ai_assertion_missing] if args.key?(:final_ai_assertion_missing)
  @inconclusive_reason = args[:inconclusive_reason] if args.key?(:inconclusive_reason)
  @name = args[:name] if args.key?(:name)
  @origin_device_execution = args[:origin_device_execution] if args.key?(:origin_device_execution)
  @results_storage_path = args[:results_storage_path] if args.key?(:results_storage_path)
  @robo_stats = args[:robo_stats] if args.key?(:robo_stats)
  @screenshot_uris = args[:screenshot_uris] if args.key?(:screenshot_uris)
  @state = args[:state] if args.key?(:state)
  @video_start_time = args[:video_start_time] if args.key?(:video_start_time)
  @video_uri = args[:video_uri] if args.key?(:video_uri)
end