Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteractionEnterText
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceInteractionEnterText
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb
Overview
A text entry action, that enters text into a particular text field, clearing any existing text in the field.
Instance Attribute Summary collapse
-
#element_bounds ⇒ Google::Apis::FirebaseappdistributionV1alpha::AndroidxCrawlerOutputRectangle
Rectangle for describing bounding boxes Corresponds to the JSON property
elementBounds. -
#text ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaDeviceInteractionEnterText
constructor
A new instance of GoogleFirebaseAppdistroV1alphaDeviceInteractionEnterText.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaDeviceInteractionEnterText
Returns a new instance of GoogleFirebaseAppdistroV1alphaDeviceInteractionEnterText.
905 906 907 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 905 def initialize(**args) update!(**args) end |
Instance Attribute Details
#element_bounds ⇒ Google::Apis::FirebaseappdistributionV1alpha::AndroidxCrawlerOutputRectangle
Rectangle for describing bounding boxes
Corresponds to the JSON property elementBounds
898 899 900 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 898 def element_bounds @element_bounds end |
#text ⇒ String
Output only. The text to enter.
Corresponds to the JSON property text
903 904 905 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 903 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
910 911 912 913 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 910 def update!(**args) @element_bounds = args[:element_bounds] if args.key?(:element_bounds) @text = args[:text] if args.key?(:text) end |