Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGoalAction
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGoalAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb
Overview
An action taken by the AI agent while attempting to accomplish a goal.
Instance Attribute Summary collapse
-
#caching_type ⇒ String
Output only.
-
#debug_info ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo
Information to help the customer understand why the agent took this action.
-
#device_action ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceAction
A high level action taken by the AI on the device, potentially involving multiple taps, text entries, waits, etc.
-
#explanation ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#terminal_action ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTerminalAction
An action taken by the AI to end the goal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaGoalAction
constructor
A new instance of GoogleFirebaseAppdistroV1alphaGoalAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaGoalAction
Returns a new instance of GoogleFirebaseAppdistroV1alphaGoalAction.
1126 1127 1128 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#caching_type ⇒ String
Output only. The type of caching used to determine the action.
Corresponds to the JSON property cachingType
1098 1099 1100 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1098 def caching_type @caching_type end |
#debug_info ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo
Information to help the customer understand why the agent took this action.
Corresponds to the JSON property debugInfo
1103 1104 1105 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1103 def debug_info @debug_info end |
#device_action ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaDeviceAction
A high level action taken by the AI on the device, potentially involving
multiple taps, text entries, waits, etc.
Corresponds to the JSON property deviceAction
1109 1110 1111 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1109 def device_action @device_action end |
#explanation ⇒ String
Output only. An explanation justifying why the action was taken.
Corresponds to the JSON property explanation
1114 1115 1116 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1114 def explanation @explanation end |
#start_time ⇒ String
Output only. The time at which the action started.
Corresponds to the JSON property startTime
1119 1120 1121 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1119 def start_time @start_time end |
#terminal_action ⇒ Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTerminalAction
An action taken by the AI to end the goal.
Corresponds to the JSON property terminalAction
1124 1125 1126 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1124 def terminal_action @terminal_action end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1131 1132 1133 1134 1135 1136 1137 1138 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1131 def update!(**args) @caching_type = args[:caching_type] if args.key?(:caching_type) @debug_info = args[:debug_info] if args.key?(:debug_info) @device_action = args[:device_action] if args.key?(:device_action) @explanation = args[:explanation] if args.key?(:explanation) @start_time = args[:start_time] if args.key?(:start_time) @terminal_action = args[:terminal_action] if args.key?(:terminal_action) end |