Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

Information to help the customer understand why the agent took this action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo

Returns a new instance of GoogleFirebaseAppdistroV1alphaGoalActionDebugInfo.



1156
1157
1158
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotated_screenshot_uriString

Output only. URI of the screenshot with elements labeled which was used by the agent. Corresponds to the JSON property annotatedScreenshotUri

Returns:

  • (String)


1149
1150
1151
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1149

def annotated_screenshot_uri
  @annotated_screenshot_uri
end

#json_uriString

Output only. Structured data explaining the agent's choice. Corresponds to the JSON property jsonUri

Returns:

  • (String)


1154
1155
1156
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1154

def json_uri
  @json_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1161
1162
1163
1164
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1161

def update!(**args)
  @annotated_screenshot_uri = args[:annotated_screenshot_uri] if args.key?(:annotated_screenshot_uri)
  @json_uri = args[:json_uri] if args.key?(:json_uri)
end