Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestCase

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

AI test cases

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaTestCase

Returns a new instance of GoogleFirebaseAppdistroV1alphaTestCase.



1644
1645
1646
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_instructionsGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaAiInstructions

Optional. Instructions for AI driven test. Corresponds to the JSON property aiInstructions



1616
1617
1618
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1616

def ai_instructions
  @ai_instructions
end

#create_timeString

Output only. Timestamp when the test case was created Corresponds to the JSON property createTime

Returns:

  • (String)


1621
1622
1623
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1621

def create_time
  @create_time
end

#dependent_test_casesArray<String>

Output only. Other test cases that depend on this test case as a prerequisite. Corresponds to the JSON property dependentTestCases

Returns:

  • (Array<String>)


1626
1627
1628
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1626

def dependent_test_cases
  @dependent_test_cases
end

#display_nameString

Required. Display name of the test case. Corresponds to the JSON property displayName

Returns:

  • (String)


1631
1632
1633
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1631

def display_name
  @display_name
end

#nameString

Identifier. The name of the test case resource. Format: projects/ project_number/apps/app/testCases/test_case` Corresponds to the JSON propertyname`

Returns:

  • (String)


1637
1638
1639
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1637

def name
  @name
end

#prerequisite_test_caseString

Optional. Test case that must be run before this test case. Corresponds to the JSON property prerequisiteTestCase

Returns:

  • (String)


1642
1643
1644
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1642

def prerequisite_test_case
  @prerequisite_test_case
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1649
1650
1651
1652
1653
1654
1655
1656
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1649

def update!(**args)
  @ai_instructions = args[:ai_instructions] if args.key?(:ai_instructions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dependent_test_cases = args[:dependent_test_cases] if args.key?(:dependent_test_cases)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @prerequisite_test_case = args[:prerequisite_test_case] if args.key?(:prerequisite_test_case)
end