Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

Configuration for automated tests

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaTestConfig

Returns a new instance of GoogleFirebaseAppdistroV1alphaTestConfig.



1700
1701
1702
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1700

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. Display name of the AI driven test. Required if the release test is created with multiple goals. Corresponds to the JSON property displayName

Returns:

  • (String)


1675
1676
1677
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1675

def display_name
  @display_name
end

#nameString

Identifier. The name of the test configuration resource. Format: projects/ project_number/apps/app/testConfig Corresponds to the JSON property name

Returns:

  • (String)


1681
1682
1683
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1681

def name
  @name
end

#results_bucketString

Optional. The custom Cloud Storage bucket where test results are stored. Format: projects/project_number/buckets/bucket`If not provided, the default test lab bucket is used. Corresponds to the JSON propertyresultsBucket`

Returns:

  • (String)


1688
1689
1690
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1688

def results_bucket
  @results_bucket
end

#robo_crawlerGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaRoboCrawler

Configuration for Robo crawler Corresponds to the JSON property roboCrawler



1693
1694
1695
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1693

def robo_crawler
  @robo_crawler
end

#test_devicesArray<Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestDevice>

Optional. Tests will be run on this list of devices Corresponds to the JSON property testDevices



1698
1699
1700
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1698

def test_devices
  @test_devices
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1705
1706
1707
1708
1709
1710
1711
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1705

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @results_bucket = args[:results_bucket] if args.key?(:results_bucket)
  @robo_crawler = args[:robo_crawler] if args.key?(:robo_crawler)
  @test_devices = args[:test_devices] if args.key?(:test_devices)
end