Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb

Overview

Configuration for automated tests

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaTestConfig

Returns a new instance of GoogleFirebaseAppdistroV1alphaTestConfig.



1685
1686
1687
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. Display name of the AI driven test. Required if the release test is created with multiple goals. Corresponds to the JSON property displayName

Returns:

  • (String)


1667
1668
1669
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1667

def display_name
  @display_name
end

#nameString

Identifier. The name of the test configuration resource. Format: projects/ project_number/apps/app/testConfig Corresponds to the JSON property name

Returns:

  • (String)


1673
1674
1675
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1673

def name
  @name
end

#robo_crawlerGoogle::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaRoboCrawler

Configuration for Robo crawler Corresponds to the JSON property roboCrawler



1678
1679
1680
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1678

def robo_crawler
  @robo_crawler
end

#test_devicesArray<Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestDevice>

Optional. Tests will be run on this list of devices Corresponds to the JSON property testDevices



1683
1684
1685
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1683

def test_devices
  @test_devices
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1690
1691
1692
1693
1694
1695
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1690

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @robo_crawler = args[:robo_crawler] if args.key?(:robo_crawler)
  @test_devices = args[:test_devices] if args.key?(:test_devices)
end