Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestQuota
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestQuota
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb
Overview
Customer quota information for ReleaseTests. Note: This quota only applies
to tests with AiInstructions and is separate from the quota which might
apply to the device time used by any tests.
Instance Attribute Summary collapse
-
#limit ⇒ Fixnum
Output only.
-
#name ⇒ String
Identifier.
-
#usage ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaTestQuota
constructor
A new instance of GoogleFirebaseAppdistroV1alphaTestQuota.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaTestQuota
Returns a new instance of GoogleFirebaseAppdistroV1alphaTestQuota.
1774 1775 1776 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#limit ⇒ Fixnum
Output only. Maximum number of ReleaseTests allotted for the current month.
Corresponds to the JSON property limit
1761 1762 1763 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1761 def limit @limit end |
#name ⇒ String
Identifier. The name of the TestQuota resource. Format: projects/
project_number/testQuota
Corresponds to the JSON property name
1767 1768 1769 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1767 def name @name end |
#usage ⇒ Fixnum
Output only. Number of ReleaseTests run in the current month
Corresponds to the JSON property usage
1772 1773 1774 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1772 def usage @usage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1779 1780 1781 1782 1783 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1779 def update!(**args) @limit = args[:limit] if args.key?(:limit) @name = args[:name] if args.key?(:name) @usage = args[:usage] if args.key?(:usage) end |