Class: Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestQuota
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappdistributionV1alpha::GoogleFirebaseAppdistroV1alphaTestQuota
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappdistribution_v1alpha/classes.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb,
lib/google/apis/firebaseappdistribution_v1alpha/representations.rb
Overview
Customer quota information for ReleaseTests. Note: This quota only applies
to tests with AiInstructions and is separate from the quota which might
apply to the device time used by any tests.
Instance Attribute Summary collapse
-
#limit ⇒ Fixnum
Output only.
-
#name ⇒ String
Identifier.
-
#usage ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaTestQuota
constructor
A new instance of GoogleFirebaseAppdistroV1alphaTestQuota.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppdistroV1alphaTestQuota
Returns a new instance of GoogleFirebaseAppdistroV1alphaTestQuota.
1758 1759 1760 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1758 def initialize(**args) update!(**args) end |
Instance Attribute Details
#limit ⇒ Fixnum
Output only. Maximum number of ReleaseTests allotted for the current month.
Corresponds to the JSON property limit
1745 1746 1747 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1745 def limit @limit end |
#name ⇒ String
Identifier. The name of the TestQuota resource. Format: projects/
project_number/testQuota
Corresponds to the JSON property name
1751 1752 1753 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1751 def name @name end |
#usage ⇒ Fixnum
Output only. Number of ReleaseTests run in the current month
Corresponds to the JSON property usage
1756 1757 1758 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1756 def usage @usage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1763 1764 1765 1766 1767 |
# File 'lib/google/apis/firebaseappdistribution_v1alpha/classes.rb', line 1763 def update!(**args) @limit = args[:limit] if args.key?(:limit) @name = args[:name] if args.key?(:name) @usage = args[:usage] if args.key?(:usage) end |